@@ -31,7 +31,7 @@
 #include <regex.h>
 
 #include "error.h"
-#include "human.h"
+#include "inttostr.h"
 #include "safe-read.h"
 #include "xstrtol.h"
 
@@ -85,7 +85,7 @@ struct control
 /* A string with a length count. */
 struct cstring
 {
-  int len;
+  unsigned int len;
   char *str;
 };
 
@@ -247,7 +247,7 @@ interrupt_handler (int sig)
   signal (sig, SIG_DFL);
 #endif
   cleanup ();
-  kill (getpid (), sig);
+  raise (sig);
 }
 
 /* Keep track of NUM chars of a partial line in buffer START.
@@ -267,11 +267,14 @@ save_to_hold_area (char *start, unsigned int num)
 
 /* Read up to MAX_N_BYTES chars from the input stream into DEST.
    Return the number of chars read. */
+/* FIXME: MAX_N_BYTES should be of type size_t, but if you pull
+   that thread, you'll find there are many other `unsigned' types
+   in this file that should also be changed.  */
 
-static int
-read_input (char *dest, unsigned int max_n_bytes)
+static size_t
+read_input (char *dest, int max_n_bytes)
 {
-  int bytes_read;
+  size_t bytes_read;
 
   if (max_n_bytes == 0)
     return 0;
@@ -281,7 +284,7 @@ read_input (char *dest, unsigned int max_n_bytes)
   if (bytes_read == 0)
     have_read_eof = TRUE;
 
-  if (bytes_read < 0)
+  if (bytes_read == SAFE_READ_ERROR)
     {
       error (0, errno, _("read error"));
       cleanup_fatal ();
@@ -735,10 +738,10 @@ dump_rest_of_file (void)
 static void
 handle_line_error (const struct control *p, int repetition)
 {
-  char buf[LONGEST_HUMAN_READABLE + 1];
+  char buf[INT_BUFSIZE_BOUND (uintmax_t)];
 
   fprintf (stderr, _("%s: `%s': line number out of range"),
-	   program_name, human_readable (p->lines_required, buf, 1, 1));
+	   program_name, umaxtostr (p->lines_required, buf));
   if (repetition)
     fprintf (stderr, _(" on repetition %d\n"), repetition);
   else
@@ -1175,10 +1178,10 @@ parse_patterns (int argc, int start, char **argv)
 		   argv[i]);
 	  if (val < last_val)
 	    {
-	      char buf[LONGEST_HUMAN_READABLE + 1];
+	      char buf[INT_BUFSIZE_BOUND (uintmax_t)];
 	      error (EXIT_FAILURE, 0,
 	       _("line number `%s' is smaller than preceding line number, %s"),
-		     argv[i], human_readable (last_val, buf, 1, 1));
+		     argv[i], umaxtostr (last_val, buf));
 	    }
 
 	  if (val == last_val)
