@@ -32,7 +32,7 @@
 #include "long-options.h"
 #include "error.h"
 #include "hard-locale.h"
-#include "human.h"
+#include "inttostr.h"
 #include "physmem.h"
 #include "posixver.h"
 #include "stdio-safer.h"
@@ -242,9 +242,6 @@ static size_t temp_dir_count;
 /* Number of allocated slots in temp_dirs.  */
 static size_t temp_dir_alloc;
 
-/* Our process ID.  */
-static pid_t process_id;
-
 /* Flag to reverse the order of all comparisons. */
 static int reverse;
 
@@ -1566,13 +1563,13 @@ checkfp (FILE *fp, char *file_name)
 	{
 	found_disorder:
 	  {
-	    char hr_buf[LONGEST_HUMAN_READABLE + 1];
 	    struct line const *disorder_line = line - 1;
 	    uintmax_t disorder_line_number =
 	      buffer_linelim (&buf) - disorder_line + line_number;
+	    char hr_buf[INT_BUFSIZE_BOUND (uintmax_t)];
 	    fprintf (stderr, _("%s: %s:%s: disorder: "),
 		     program_name, file_name,
-		     human_readable (disorder_line_number, hr_buf, 1, 1));
+		     umaxtostr (disorder_line_number, hr_buf));
 	    write_bytes (disorder_line->text, disorder_line->length, stderr,
 			 _("standard error"));
 	    disordered = 1;
@@ -2096,7 +2093,7 @@ sighandler (int sig)
   signal (sig, SIG_DFL);
 #endif
 
-  kill (process_id, sig);
+  raise (sig);
 }
 
 /* Set the ordering options for KEY specified in S.
@@ -2161,7 +2158,6 @@ main (int argc, char **argv)
   struct keyfield *key;
   struct keyfield gkey;
   char const *s;
-  int i;
   int c = 0;
   int checkonly = 0, mergeonly = 0, nfiles = 0;
   int posix_pedantic = (getenv ("POSIXLY_CORRECT") != NULL);
@@ -2172,13 +2168,12 @@ main (int argc, char **argv)
   char *minus = "-", **files;
   char const *outfile = minus;
   static int const sigs[] = { SIGHUP, SIGINT, SIGPIPE, SIGTERM };
-  int nsigs = sizeof sigs / sizeof *sigs;
+  unsigned nsigs = sizeof sigs / sizeof *sigs;
 #ifdef SA_NOCLDSTOP
   struct sigaction oldact, newact;
 #endif
 
   program_name = argv[0];
-  process_id = getpid ();
   setlocale (LC_ALL, "");
   bindtextdomain (PACKAGE, LOCALEDIR);
   textdomain (PACKAGE);
@@ -2217,26 +2212,32 @@ main (int argc, char **argv)
   xmemcoll_exit_failure = SORT_FAILURE;
 
 #ifdef SA_NOCLDSTOP
-  sigemptyset (&caught_signals);
-  for (i = 0; i < nsigs; i++)
-    sigaddset (&caught_signals, sigs[i]);
-  newact.sa_handler = sighandler;
-  newact.sa_mask = caught_signals;
-  newact.sa_flags = 0;
+  {
+    unsigned i;
+    sigemptyset (&caught_signals);
+    for (i = 0; i < nsigs; i++)
+      sigaddset (&caught_signals, sigs[i]);
+    newact.sa_handler = sighandler;
+    newact.sa_mask = caught_signals;
+    newact.sa_flags = 0;
+  }
 #endif
 
-  for (i = 0; i < nsigs; i++)
-    {
-      int sig = sigs[i];
+  {
+    unsigned i;
+    for (i = 0; i < nsigs; i++)
+      {
+	int sig = sigs[i];
 #ifdef SA_NOCLDSTOP
-      sigaction (sig, NULL, &oldact);
-      if (oldact.sa_handler != SIG_IGN)
-	sigaction (sig, &newact, NULL);
+	sigaction (sig, NULL, &oldact);
+	if (oldact.sa_handler != SIG_IGN)
+	  sigaction (sig, &newact, NULL);
 #else
-      if (signal (sig, SIG_IGN) != SIG_IGN)
-	signal (sig, sighandler);
+	if (signal (sig, SIG_IGN) != SIG_IGN)
+	  signal (sig, sighandler);
 #endif
-    }
+      }
+  }
 
   gkey.sword = gkey.eword = -1;
   gkey.ignore = NULL;
